package com.iden.bms.controller;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.iden.bms.service.SysLogService;
import com.iden.common.annotation.Permission;
import com.iden.common.exception.BDException;
import com.iden.common.logaspect.LogAnnotation;
import com.iden.common.logaspect.OperateType;
import com.iden.common.util.PageResult;

import com.iden.common.util.WebPageUtils;
import com.iden.common.vo.SysLogVO;
import com.iden.common.vo.PageReqVO;
import com.iden.common.vo.UserLoginedConvertVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @Author: lilt
 * @Date: 2021/5/26
 * @Desc:
 */
@RestController
@Api(value = "SysLogController", tags = { "系统日志管理" })
@Slf4j
@RequestMapping("/bms/sysLog")
@Permission
public class SysLogController {

    @Autowired
    private SysLogService sysLogService;

    
    @GetMapping("/listSysLog")
    @ApiOperation(value = "系统日志列表分页 ")
    @ApiImplicitParams(value = {

            @ApiImplicitParam(paramType = "query", name = "username", value = "操作账号"),
            @ApiImplicitParam(paramType = "query", name = "logType", value = "日志类型"),
            @ApiImplicitParam(paramType = "query", name = "createTime", value = "操作日期")

    })
    public PageResult<List<SysLogVO>> listSysLog(HttpServletRequest request, @RequestHeader(value = "token") String token,
                                                 @RequestParam(value = "username", required = false) String username,
                                                 @RequestParam(value = "logType", required = false) String logType,
                                                 @RequestParam(value = "createTime", required = false) String createTime,
                                                 PageReqVO pageReqVo){
        try {
            UserLoginedConvertVO loginUser = WebPageUtils.getCurrentLoginedUser(request);
            IPage<SysLogVO> pageResponse = this.sysLogService.listSysLog(username,logType,createTime,loginUser ,pageReqVo);
            return PageResult.success(pageResponse.getRecords(),pageResponse.getCurrent(),pageResponse.getSize(),pageResponse.getTotal());
        }catch (BDException e) {
            log.error("系统日志列表查询-分页列表出现异常",e);
            return  PageResult.error(e.getMessage());
        } catch (Exception e) {
            log.error("系统日志管理: 系统日志列表查询出现异常",e);
            return PageResult.error( "获取列表失败");
        }
    }


    /**
     * 导出列表
     * @param
     * @return
     */
    @ApiOperation(value = "导出Excel")
    @ApiImplicitParams(value = {
            @ApiImplicitParam(paramType = "query", name = "username", value = "操作账号"),
            @ApiImplicitParam(paramType = "query", name = "logType", value = "日志类型"),
            @ApiImplicitParam(paramType = "query", name = "createTime", value = "操作日期")

    })
    @GetMapping({"/exportToExcel"})
    @LogAnnotation(
            type = OperateType.EXPORT,
            moduleName = "导出系统日志列表",
            description = "导出系统日志列表"
    )
    public void exportToExcel(HttpServletRequest request,@RequestHeader(name = "token", required = true) String token,
                              @RequestParam(value = "username", required = false) String username,
                              @RequestParam(value = "logType", required = false) String logType,
                              @RequestParam(value = "createTime", required = false) String createTime,
                              HttpServletResponse response) {
        try {
            UserLoginedConvertVO loginUser = WebPageUtils.getCurrentLoginedUser(request);
            this.sysLogService.exportToExcel(username,logType,createTime,loginUser,response);
        } catch (BDException e) {
            log.error("导出系统日志列表出现异常",e);
        } catch (Exception e) {
            log.error("系统日志管理: 导出系统日志列表出现异常",e);
        }
    }

}
