package com.iden.bms.schedule;

/**
 * @author wyy
 * @subject
 * @creat 2023/2/18
 */

import com.iden.bms.service.StreamService;
import com.iden.common.cache.RedisKeyConstant;
import com.iden.common.cache.RedisUtil;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.util.UUID;

/**
 * 定时读取目录下图片，调用人脸识别引擎，把特征码入库
 */
@Configuration
@EnableScheduling
@EnableAsync
public class StreamSchedule {
    @Resource
    private RedisUtil redisUtil;
    @Resource
    private StreamService streamService;
    private static final Logger logger = LogManager.getLogger(StreamSchedule.class);
    /**
     * 处理摄像头上传的视频
     */
    @Async
    @Scheduled(cron = "30 1/3 * * * ?")
    public void handleVideoStream() {
        logger.info("StreamSchedule.handleStreamVideo start----------" );
        String key = RedisKeyConstant.HANDLE_VIDEO_STREAM;
        String requestId = UUID.randomUUID().toString();
        boolean result = redisUtil.tryLock(key,requestId,10 * 60);
        try {
            if (result) {
                logger.info("StreamSchedule.handleVideoStream start----------result=="+result );
                streamService.transferVideo();
            }
        } catch (Exception e) {
            e.getMessage();
        }  finally {
            redisUtil.releaseLock(key,requestId);
        }
    }
}
